pub enum InfixOperator {
Show 37 variants
Equal,
NotEqual,
LessThan,
LessEqual,
GreaterThan,
GreaterEqual,
And,
Or,
Xor,
Add,
Subtract,
Multiply,
Divide,
Modulo,
Concat,
Like,
ILike,
NotLike,
NotILike,
Glob,
NotGlob,
Regexp,
NotRegexp,
Is,
IsNot,
IsDistinctFrom,
IsNotDistinctFrom,
Index,
JsonAccess,
JsonAccessText,
VectorDistance,
BitwiseAnd,
BitwiseOr,
BitwiseXor,
LeftShift,
RightShift,
Other,
}Expand description
Infix operator type (pre-computed at parse time for zero-allocation evaluation) This is a key optimization: instead of string comparison for every row, we match on a small enum which is faster and allocation-free.
Variants
Equal
NotEqual
LessThan
LessEqual
GreaterThan
GreaterEqual
And
Or
Xor
Add
Subtract
Multiply
Divide
Modulo
Concat
Like
ILike
NotLike
NotILike
Glob
NotGlob
Regexp
NotRegexp
Is
IsNot
IsDistinctFrom
IsNotDistinctFrom
Index
JsonAccess
JsonAccessText
VectorDistance
BitwiseAnd
BitwiseOr
BitwiseXor
LeftShift
RightShift
Other
Implementations